@@ -49,6 +49,7 @@
 #include "gst-audio-play.h"
 #include "gedit-message-area.h"
 #include "cheese-no-camera.h"
+#include "cheese-prefs-dialog.h"
 
 #define SHUTTER_SOUNDS 5
 
@@ -58,7 +59,6 @@ typedef enum
   WEBCAM_MODE_VIDEO
 } WebcamMode;
 
-
 typedef struct 
 {
   gboolean recording;
@@ -114,7 +114,9 @@ typedef struct
   GtkActionGroup *actions_account_photo;
   GtkActionGroup *actions_countdown;
   GtkActionGroup *actions_effects;
+  GtkActionGroup *actions_preferences;
   GtkActionGroup *actions_file;
+  GtkActionGroup *actions_sendto;
   GtkActionGroup *actions_flickr;
   GtkActionGroup *actions_fspot;
   GtkActionGroup *actions_mail;
@@ -229,11 +231,15 @@ cheese_window_cmd_close (GtkWidget *widget, CheeseWindow *cheese_window)
   g_object_unref (cheese_window->actions_countdown);
   g_object_unref (cheese_window->actions_effects);
   g_object_unref (cheese_window->actions_file);
+  g_object_unref (cheese_window->actions_sendto);
   g_object_unref (cheese_window->actions_flickr);
   g_object_unref (cheese_window->actions_fspot);
   g_object_unref (cheese_window->actions_mail);
   g_object_unref (cheese_window->actions_photo);
   g_object_unref (cheese_window->actions_toggle);
+  g_object_unref (cheese_window->actions_effects);
+  g_object_unref (cheese_window->actions_preferences);
+  g_object_unref (cheese_window->actions_file);
   g_object_unref (cheese_window->actions_video);
   g_object_unref (cheese_window->ui_manager);
   g_object_unref (cheese_window->gconf);
@@ -377,8 +383,8 @@ cheese_window_move_all_media_to_trash (GtkWidget *widget, CheeseWindow *cheese_w
   char *filename;
   GFile *file;
   GList *files_list = NULL;
-  GDir *dir;
-  char *path;
+  GDir *dir_videos, *dir_photos;
+  char *path_videos, *path_photos;
   const char *name;
 
   prompt = g_strdup_printf (_("Really move all photos and videos to the trash?"));
@@ -400,14 +406,14 @@ cheese_window_move_all_media_to_trash (GtkWidget *widget, CheeseWindow *cheese_w
   if (response !=  GTK_RESPONSE_OK)
     return;
 
-  path = cheese_fileutil_get_media_path ();
-  dir = g_dir_open (path, 0, NULL);
-  while ((name = g_dir_read_name (dir)) != NULL)
+  //delete all videos
+  path_videos = cheese_fileutil_get_video_path ();
+  dir_videos = g_dir_open (path_videos, 0, NULL);
+  while ((name = g_dir_read_name (dir_videos)) != NULL)
   {
-    if (g_str_has_suffix (name, PHOTO_NAME_SUFFIX) || 
-        g_str_has_suffix (name, VIDEO_NAME_SUFFIX))
+    if (g_str_has_suffix (name, VIDEO_NAME_SUFFIX))
     {
-      filename = g_strjoin (G_DIR_SEPARATOR_S, path, name, NULL);
+      filename = g_strjoin (G_DIR_SEPARATOR_S, path_videos, name, NULL);
       file = g_file_new_for_path (filename);
 
       files_list = g_list_append (files_list, file);
@@ -416,7 +422,25 @@ cheese_window_move_all_media_to_trash (GtkWidget *widget, CheeseWindow *cheese_w
   }
   cheese_window_cmd_move_file_to_trash (cheese_window, files_list);
   g_list_free (files_list);
-  g_dir_close(dir);
+  g_dir_close (dir_videos);
+  
+  //delete all videos
+  path_photos = cheese_fileutil_get_photo_path ();
+  dir_photos = g_dir_open (path_photos, 0, NULL);
+  while ((name = g_dir_read_name (dir_photos)) != NULL)
+  {
+    if (g_str_has_suffix (name, PHOTO_NAME_SUFFIX))
+    {
+      filename = g_strjoin (G_DIR_SEPARATOR_S, path_photos, name, NULL);
+      file = g_file_new_for_path (filename);
+
+      files_list = g_list_append (files_list, file);
+      g_free (filename);
+    }
+  }
+  cheese_window_cmd_move_file_to_trash (cheese_window, files_list);
+  g_list_free (files_list);
+  g_dir_close (dir_photos);
 }
 
 static void
@@ -434,7 +458,7 @@ cheese_window_move_media_to_trash (GtkWidget *widget, CheeseWindow *cheese_windo
     return;
 
   file = g_file_new_for_path (filename);
-  g_free(filename);
+  g_free (filename);
 
   files_list = g_list_append (files_list, file);
   cheese_window_cmd_move_file_to_trash (cheese_window, files_list);
@@ -500,7 +524,7 @@ cheese_window_cmd_set_about_me_photo (GtkWidget *widget, CheeseWindow *cheese_wi
       }
       g_free (*data);
     }
-    g_free(filename);
+    g_free (filename);
     g_object_unref (pixbuf);
   }
 }
@@ -524,6 +548,10 @@ cheese_window_cmd_command_line (GtkAction *action, CheeseWindow *cheese_window)
                                     basename, filename);
     g_free (basename);
   }
+  if (strcmp (action_name, "SendTo") == 0)
+  {
+    command_line = g_strdup_printf ("nautilus-sendto %s", filename);
+  }
   else if (strcmp (action_name, "ExportToFSpot") == 0)
   {
     char *dirname =  g_path_get_dirname (filename);
@@ -564,9 +592,9 @@ cheese_window_cmd_help_contents (GtkAction *action, CheeseWindow *cheese_window)
                                 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                                 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, 
                                 _("Unable to open help file for Cheese"));
-    gtk_dialog_run(GTK_DIALOG(d));
-    gtk_widget_destroy(d);
-    g_error_free(error);
+    gtk_dialog_run (GTK_DIALOG (d));
+    gtk_widget_destroy (d);
+    g_error_free (error);
   }
 }
 
@@ -704,7 +732,6 @@ cheese_window_effect_button_pressed_cb (GtkWidget *widget, CheeseWindow *cheese_
   else
   {
     gtk_notebook_set_current_page (GTK_NOTEBOOK (cheese_window->notebook), 1);
-    gtk_label_set_text_with_mnemonic (GTK_LABEL (cheese_window->label_effects), _("_Back"));
     gtk_widget_set_sensitive (GTK_WIDGET (cheese_window->take_picture), FALSE);
     gtk_action_group_set_sensitive (cheese_window->actions_photo, FALSE);
     gtk_action_group_set_sensitive (cheese_window->actions_video, FALSE);
@@ -941,6 +968,13 @@ cheese_window_action_button_clicked_cb (GtkWidget *widget, CheeseWindow *cheese_
   }
 }
 
+static void 
+cheese_window_preferences_cb (GtkAction *action, CheeseWindow *cheese_window)
+{
+  cheese_prefs_dialog_run (cheese_window->window, cheese_window->gconf,
+                           cheese_window->webcam);
+}
+
 static const GtkActionEntry action_entries_main[] = {
   {"Cheese", NULL, N_("_Cheese")},
 
@@ -963,6 +997,10 @@ static const GtkToggleActionEntry action_entries_effects[] = {
   {"Effects", NULL, N_("_Effects"), NULL, NULL, G_CALLBACK (cheese_window_effect_button_pressed_cb), FALSE},
 };
 
+static const GtkActionEntry action_entries_preferences[] = {
+  {"Preferences", GTK_STOCK_PREFERENCES, N_("Preferences"), NULL, NULL, G_CALLBACK (cheese_window_preferences_cb)},
+};
+
 static const GtkRadioActionEntry action_entries_toggle[] = {
   {"Photo", NULL, N_("_Photo"), NULL, NULL, 0},
   {"Video", NULL, N_("_Video"), NULL, NULL, 1},
@@ -990,6 +1028,10 @@ static const GtkActionEntry action_entries_mail[] = {
   {"SendByMail", NULL, N_("Send by _Mail"), NULL, NULL, G_CALLBACK (cheese_window_cmd_command_line)},
 };
 
+static const GtkActionEntry action_entries_sendto[] = {
+  {"SendTo", NULL, N_("Send _To"), NULL, NULL, G_CALLBACK (cheese_window_cmd_command_line)},
+};
+
 static const GtkActionEntry action_entries_fspot[] = {
   {"ExportToFSpot", NULL, N_("Export to F-_Spot"), NULL, NULL, G_CALLBACK (cheese_window_cmd_command_line)},
 };
@@ -1194,6 +1236,10 @@ cheese_window_create_window (CheeseWindow *cheese_window)
                                                                           "ActionsEffects", 
                                                                           action_entries_effects, 
                                                                           G_N_ELEMENTS (action_entries_effects));
+  cheese_window->actions_preferences = cheese_window_action_group_new (cheese_window, 
+                                                                       "ActionsPreferences", 
+                                                                       action_entries_preferences, 
+                                                                       G_N_ELEMENTS (action_entries_preferences));
   cheese_window->actions_file = cheese_window_action_group_new (cheese_window, 
                                                                 "ActionsFile", 
                                                                 action_entries_file, 
@@ -1219,8 +1265,25 @@ cheese_window_create_window (CheeseWindow *cheese_window)
                                                                 "ActionsMail", 
                                                                 action_entries_mail, 
                                                                 G_N_ELEMENTS (action_entries_mail));
-  path = g_find_program_in_path ("gnome-open");
-  gtk_action_group_set_visible (cheese_window->actions_mail, path != NULL);
+  cheese_window->actions_sendto = cheese_window_action_group_new (cheese_window, 
+                                                                  "ActionsSendTo", 
+                                                                  action_entries_sendto, 
+                                                                  G_N_ELEMENTS (action_entries_sendto));
+
+  /* handling and activation of send to/send mail actions. We only show one send mail action */
+  path = g_find_program_in_path ("nautilus-sendto");
+  gboolean nautilus_sendto = (path != NULL);
+  if (nautilus_sendto)
+  {
+    gtk_action_group_set_visible (cheese_window->actions_sendto, TRUE);
+    gtk_action_group_set_visible (cheese_window->actions_mail, FALSE);
+  }
+  else
+  {
+    path = g_find_program_in_path ("gnome-open");
+    gtk_action_group_set_visible (cheese_window->actions_mail, path != NULL);
+    gtk_action_group_set_visible (cheese_window->actions_sendto, FALSE);
+  }
   g_free (path);
 
   cheese_window->actions_fspot = cheese_window_action_group_new (cheese_window, 
@@ -1306,11 +1369,16 @@ void
 setup_camera (CheeseWindow *cheese_window)
 {
   char *webcam_device = NULL;
+  int x_resolution;
+  int y_resolution;
   GtkWidget *message_area;
+  
+  g_object_get (cheese_window->gconf, "gconf_prop_x_resolution", &x_resolution,
+                "gconf_prop_y_resolution", &y_resolution, NULL);
 
-  g_object_get (cheese_window->gconf, "gconf_prop_webcam", &webcam_device, NULL);
-
-  cheese_window->webcam = cheese_webcam_new (cheese_window->screen, webcam_device);
+  cheese_window->webcam = cheese_webcam_new (cheese_window->screen, 
+                                             webcam_device, x_resolution,
+                                             y_resolution);
   g_free (webcam_device);
 
   cheese_webcam_setup (cheese_window->webcam);
@@ -1338,8 +1406,8 @@ setup_camera (CheeseWindow *cheese_window)
 
     cheese_window_set_message_area (cheese_window, message_area);
   }
-  gdk_threads_leave ();
   gtk_widget_set_sensitive (GTK_WIDGET (cheese_window->take_picture), TRUE);
+  gdk_threads_leave ();
 }
 
 void
@@ -1347,7 +1415,7 @@ cheese_window_init ()
 {
   CheeseWindow *cheese_window;
 
-  cheese_window = g_new (CheeseWindow, 1);
+  cheese_window = g_new0 (CheeseWindow, 1);
 
   cheese_window->gconf = cheese_gconf_new ();
   cheese_window->audio_play_counter = 0;
